.. _datasets:

Datasets
========

Generate toy data
-----------------
.. currentmodule:: skchange.datasets

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    generate_anomalous_data
    generate_changing_data
    generate_alternating_data
    add_linspace_outliers

Load real datasets
------------------

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    load_hvac_system_data
